[![Build Status](https://travis-ci.org/csdms/standard_names.svg?branch=master)](https://travis-ci.org/csdms/standard_names)
[![Build status](https://ci.appveyor.com/api/projects/status/xb4lalkn0603ac1o/branch/master?svg=true)](https://ci.appveyor.com/project/mcflugen/standard-names/branch/master)
[![Documentation Status](https://readthedocs.org/projects/standard-names/badge/?version=latest)](http://standard-names.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/csdms/standard_names/badge.svg?branch=master)](https://coveralls.io/github/csdms/standard_names?branch=master)
[![Anaconda-Server Badge](https://anaconda.org/csdms/standard_names/badges/version.svg)](https://anaconda.org/csdms/standard_names)
[![Anaconda-Server Badge](https://anaconda.org/csdms/standard_names/badges/installer/conda.svg)](https://conda.anaconda.org/csdms)
[![Anaconda-Server Badge](https://anaconda.org/csdms/standard_names/badges/downloads.svg)](https://anaconda.org/csdms/standard_names)


standard_names
==============

Python utilities for working with CSDMS standard names.

Links
-----

*  [Source code](http://github.com/csdms/standard_names): The
   *standard_names* source code repository.
*  [Documentation](http://standard-names.readthedocs.io/): User documentation
   for *standard_names*
*  [Get](http://standard-names.readthedocs.io/en/latest/getting.html):
   Installation instructions
*  [Registry](http://github.com/csdms/standard_names_registry): The
   official registry of CSDMS Standard Names.
